@@ -740,7 +740,7 @@ void Dailymotion::getFullVideo(QString id) {
     this->setBusy(true, tr("Retrieving video details"));
 
     if (id.size() > 6) {
-        id = id.section('/', -1).left(6);
+        id = id.section('/', -1).section('_', 0, 0);
     }
 
     QUrl url("https://api.dailymotion.com/video/" + id);
