@@ -3,6 +3,7 @@
 
 #include <QObject>
 
+class CookieJar;
 class Settings;
 class Database;
 class VideoLauncher;
@@ -38,6 +39,7 @@ private slots:
     
 private:
     QNetworkAccessManager *m_nam;
+    CookieJar *m_jar;
     Settings *m_settings;
     Database *m_database;
     VideoLauncher *m_launcher;
