@@ -1,13 +1,14 @@
 #include "settings.h"
-#include <qplatformdefs.h>
 #include <QDir>
 #include <QDesktopServices>
 #include <QNetworkProxy>
 #include <QAuthenticator>
-#ifdef Q_OS_SYMBIAN
+#if (defined (SYMBIAN_OS)) && (defined (CUTETUBE_PLAYER_ENABLED))
 #include <QSystemDeviceInfo>
 #endif
 
+Settings* settingsInstance = 0;
+
 Settings::Settings(QObject *parent) :
     QSettings(QString("cuteTube"), QString("cuteTube"), parent),
     m_autoTransfers(true),
@@ -15,6 +16,8 @@ Settings::Settings(QObject *parent) :
     m_safeSearch(false),
     m_searchSite(Services::YouTube),
     m_showSearchSite(true),
+    m_searchOrder(Queries::Relevance),
+    m_showSearchOrder(true),
     m_searchTime(Queries::AllTime),
     m_showSearchTime(false),
     m_searchDuration(Queries::Any),
@@ -23,49 +26,79 @@ Settings::Settings(QObject *parent) :
     m_showSearchType(true),
     m_languageFilter("all"),
     m_showSearchLanguage(false),
+  #if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
     m_theme("dark"),
     m_activeColor("#0881cb"),
     m_activeColorString("color7"),
+  #endif
     m_language("en"),
+  #ifdef CUTETUBE_PLAYER_ENABLED
     m_mediaplayer("cutetube"),
+  #ifndef SYMBIAN_OS
     m_backgroundPlaybackEnabled(false),
+  #endif
+  #else
+    m_mediaplayer("mediaplayer"),
+  #endif
     m_orientation(ScreenOrientation::Automatic),
     m_monitorClipboard(false),
     m_proxyType(NetworkProxyType::HttpProxy),
     m_proxyPort(80),
+  #ifdef Q_WS_MAEMO_5
     m_eventFeedEnabled(false),
     m_eventFeedInstalled(false),
+  #endif
+  #ifdef CUTETUBE_PLAYER_ENABLED
     m_cuteTubePlayerEnabled(true)
+  #else
+    m_cuteTubePlayerEnabled(false)
+  #endif
 {
+    if (!settingsInstance) {
+        settingsInstance = this;
+    }
 }
 
 Settings::~Settings() {
     this->saveSettings();
 }
 
+Settings* Settings::instance() {
+    return settingsInstance;
+}
+
 void Settings::restoreSettings() {
     this->beginGroup("Media");
-    this->setYouTubePlaybackQualitySet(this->value("youtubePlaybackQuality", QVariantList()).toList());
-    this->setYouTubeDownloadQualitySet(this->value("youtubeDownloadQuality", QVariantList()).toList());
-    this->setDailymotionPlaybackQualitySet(this->value("dailymotionPlaybackQuality", QVariantList()).toList());
-    this->setDailymotionDownloadQualitySet(this->value("dailymotionDownloadQuality", QVariantList()).toList());
+    this->setYouTubePlaybackFormats(this->value("youtubePlaybackFormats", QVariantList() << Videos::LQ).toList());
+    this->setYouTubeDownloadFormats(this->value("youtubeDownloadFormats", QVariantList() << Videos::LQ).toList());
+    this->setDailymotionPlaybackFormats(this->value("dailymotionPlaybackFormats", QVariantList() << Videos::Normal).toList());
+    this->setDailymotionDownloadFormats(this->value("dailymotionDownloadFormats", QVariantList() << Videos::Normal).toList());
 #ifdef Q_WS_MAEMO_5
-    this->setVimeoPlaybackQualitySet(this->value("vimeoPlaybackQuality", QVariantList()).toList());
-    this->setVimeoDownloadQualitySet(this->value("vimeoDownloadQuality", QVariantList()).toList());
+    this->setVimeoPlaybackFormats(this->value("vimeoPlaybackFormats", QVariantList() << Videos::LQ).toList());
+    this->setVimeoDownloadFormats(this->value("vimeoDownloadFormats", QVariantList() << Videos::LQ).toList());
 #else
-    this->setVimeoPlaybackQualitySet(this->value("vimeoPlaybackQuality", QVariantList() << "sd").toList());
-    this->setVimeoDownloadQualitySet(this->value("vimeoDownloadQuality", QVariantList() << "sd").toList());
+    this->setVimeoPlaybackFormats(this->value("vimeoPlaybackFormats", QVariantList() << Videos::LQ << Videos::Normal).toList());
+    this->setVimeoDownloadFormats(this->value("vimeoDownloadFormats", QVariantList() << Videos::LQ << Videos::Normal).toList());
 #endif
     this->setUploadAttribute(this->value("uploadAttribute", tr("Uploaded via cuteTube")).toString());
-#ifdef Q_OS_SYMBIAN
-    this->setCuteTubePlayerEnabled();
-    this->setMediaPlayer(this->cuteTubePlayerEnabled() ? this->value("mediaPlayer", QString("cutetube")).toString() : QString("mediaplayer"));
-#else
-    this->setMediaPlayer(this->value("mediaPlayer", QString("cutetube")).toString());
-    this->setMediaPlayerCommand(this->value("mediaPlayerCommand", QString()).toString());
+#ifdef SYMBIAN_OS
+#ifdef CUTETUBE_PLAYER_ENABLED
+    using namespace QtMobility;
+    QSystemDeviceInfo info;
+    this->setCuteTubePlayerEnabled((info.model() == "700") || (info.model() == "701") || (info.model() == "808"));
+
+    if (this->cuteTubePlayerEnabled()) {
+        this->setMediaPlayer(this->value("mediaPlayer", QString("cutetube")).toString());
+    }
 #endif
-#ifdef MEEGO_EDITION_HARMATTAN
+#else
+#ifdef CUTETUBE_PLAYER_ENABLED
+    this->setMediaPlayer(this->value("mediaPlayer", QString("cutetube")).toString());
     this->setBackgroundPlaybackEnabled(this->value("backgroundPlaybackEnabled", false).toBool());
+#else
+    this->setMediaPlayer(this->value("mediaPlayer", QString("mediaplayer")).toString());
+#endif
+    this->setMediaPlayerCommand(this->value("mediaPlayerCommand", QString()).toString());
 #endif
     this->setLanguageFilter(this->value("languageFilter", QString("all")).toString());
     this->endGroup();
@@ -75,7 +108,7 @@ void Settings::restoreSettings() {
     this->setMaximumConcurrentTransfers(this->value("maximumConcurrentTransfers", 1).toInt());
 #if (defined (Q_WS_MAEMO_5)) || (defined (MEEGO_EDITION_HARMATTAN))
     this->setDownloadPath(this->value("downloadPath", QString("/home/user/MyDocs/cuteTube/")).toString());
-#elif defined (Q_OS_SYMBIAN)
+#elif defined (SYMBIAN_OS)
     this->setDownloadPath(this->value("downloadPath", QString("E:/cuteTube/")).toString());
 #else
     this->setDownloadPath(this->value("downloadPath", QDesktopServices::storageLocation(QDesktopServices::HomeLocation).append("/cuteTube/")).toString());
@@ -84,30 +117,36 @@ void Settings::restoreSettings() {
 
     this->beginGroup("Search");
     this->setSafeSearch(this->value("safeSearch", false).toBool());
-    this->setSearchSite(static_cast<Services::VideoService>(this->value("searchSite", 0).toInt()));
+    this->setSearchSite(static_cast<Services::VideoService>(this->value("searchSite", Services::YouTube).toInt()));
     this->setShowSearchSite(this->value("showSearchSite", true).toBool());
-    this->setSearchOrder(static_cast<Queries::QueryOrder>(this->value("searchOrder", 0).toInt()));
+    this->setSearchOrder(static_cast<Queries::QueryOrder>(this->value("searchOrder", Queries::Relevance).toInt()));
     this->setShowSearchOrder(this->value("showSearchOrder", true).toBool());
-    this->setSearchTime(static_cast<Queries::TimeFilter>(this->value("searchTime", 0).toInt()));
+    this->setSearchTime(static_cast<Queries::TimeFilter>(this->value("searchTime", Queries::AllTime).toInt()));
     this->setShowSearchTime(this->value("showSearchTime", false).toBool());
-    this->setSearchDuration(static_cast<Queries::DurationFilter>(this->value("searchDuration", 0).toInt()));
+    this->setSearchDuration(static_cast<Queries::DurationFilter>(this->value("searchDuration", Queries::Any).toInt()));
     this->setShowSearchDuration(this->value("showSearchDuration", false).toBool());
-    this->setSearchType(static_cast<Queries::QueryType>(this->value("searchType", 0).toInt()));
+    this->setSearchType(static_cast<Queries::QueryType>(this->value("searchType", Queries::Videos).toInt()));
     this->setShowSearchType(this->value("showSearchType", true).toBool());
     this->setShowSearchLanguage(this->value("showSearchLanguage", true).toBool());
     this->endGroup();
 
-#if (defined (Q_WS_MAEMO_5)) || (defined (MEEGO_EDITION_HARMATTAN))
+#ifdef Q_WS_MAEMO_5
     this->beginGroup("Events");
     this->setEventFeedEnabled((this->value("eventFeedEnabled", false).toBool()) && (this->eventFeedInstalled()));
     this->endGroup();
 #endif
 
+#if (defined (SYMBIAN_OS)) || (defined (MEEGO_EDITION_HARMATTAN))
     this->beginGroup("Appearance");
+#ifdef SYMBIAN_OS
     this->setTheme(this->value("theme", QString("dark")).toString());
+#else
+    this->setTheme(this->value("theme", QString("dark_plain")).toString());
     this->setActiveColor(this->value("activeColor", QString("#0881cb")).toString());
     this->setActiveColorString(this->value("activeColorString", QString("color7")).toString());
+#endif
     this->endGroup();
+#endif
 
     this->beginGroup("System");
     this->setLanguage(this->value("language", QString("en")).toString());
@@ -124,18 +163,20 @@ void Settings::restoreSettings() {
 
 void Settings::saveSettings() {
     this->beginGroup("Media");
-    this->setValue("youtubePlaybackQuality", this->toVariantList(m_youtubePlaybackSet));
-    this->setValue("youtubeDownloadQuality", this->toVariantList(m_youtubeDownloadSet));
-    this->setValue("dailymotionPlaybackQuality", this->toVariantList(m_dailymotionPlaybackSet));
-    this->setValue("dailymotionDownloadQuality", this->toVariantList(m_dailymotionDownloadSet));
-    this->setValue("vimeoPlaybackQuality", this->toVariantList(m_vimeoPlaybackSet));
-    this->setValue("vimeoDownloadQuality", this->toVariantList(m_vimeoDownloadSet));
+    this->setValue("youtubePlaybackFormats", this->toVariantList(m_youtubePlaybackFormats));
+    this->setValue("youtubeDownloadFormats", this->toVariantList(m_youtubeDownloadFormats));
+    this->setValue("dailymotionPlaybackFormats", this->toVariantList(m_dailymotionPlaybackFormats));
+    this->setValue("dailymotionDownloadFormats", this->toVariantList(m_dailymotionDownloadFormats));
+    this->setValue("vimeoPlaybackFormats", this->toVariantList(m_vimeoPlaybackFormats));
+    this->setValue("vimeoDownloadFormats", this->toVariantList(m_vimeoDownloadFormats));
     this->setValue("uploadAttribute", this->uploadAttribute());
+#if (!defined SYMBIAN_OS) || (defined (CUTETUBE_PLAYER_ENABLED))
     this->setValue("mediaPlayer", this->mediaPlayer());
-#ifdef MEEGO_EDITION_HARMATTAN
+#endif
+#ifndef SYMBIAN_OS
+#ifdef CUTETUBE_PLAYER_ENABLED
     this->setValue("backgroundPlaybackEnabled", this->backgroundPlaybackEnabled());
 #endif
-#ifndef Q_OS_SYMBIAN
     this->setValue("mediaPlayerCommand", this->mediaPlayerCommand());
 #endif
     this->setValue("languageFilter", this->languageFilter());
@@ -162,17 +203,19 @@ void Settings::saveSettings() {
     this->setValue("showSearchLanguage", this->showSearchLanguage());
     this->endGroup();
 
-#if (defined (Q_WS_MAEMO_5)) || (defined (MEEGO_EDITION_HARMATTAN))
+#ifdef Q_WS_MAEMO_5
     this->beginGroup("Events");
     this->setValue("eventFeedEnabled", (this->eventFeedEnabled()) && (this->eventFeedInstalled()));
     this->endGroup();
 #endif
 
-#if (defined (Q_OS_SYMBIAN)) || (defined (MEEGO_EDITITION_HARMATTAN))
+#if (defined (SYMBIAN_OS)) || (defined (MEEGO_EDITION_HARMATTAN))
     this->beginGroup("Appearance");
     this->setValue("theme", this->theme());
+#ifndef SYMBIAN_OS
     this->setValue("activeColor", this->activeColor());
     this->setValue("activeColorString", this->activeColorString());
+#endif
     this->endGroup();
 #endif
 
@@ -189,286 +232,306 @@ void Settings::saveSettings() {
 }
 
 QVariantList Settings::toVariantList(const QSet<int> &set) {
-    QVariantList varList;
-    QList<int> list = set.toList();
+    QVariantList variantList;
 
-    while (!list.isEmpty()) {
-        varList.append(list.takeFirst());
+    foreach (int i, set) {
+        variantList.append(i);
     }
 
-    return varList;
+    return variantList;
 }
 
-QVariantList Settings::toVariantList(const QSet<QByteArray> &set) {
-    QVariantList varList;
-    QList<QByteArray> list = set.toList();
-
-    while (!list.isEmpty()) {
-        varList.append(list.takeFirst());
+void Settings::setYouTubePlaybackFormats(QVariantList formats) {
+    while (!formats.isEmpty()) {
+        m_youtubePlaybackFormats.insert(formats.takeFirst().toInt());
     }
 
-    return varList;
-}
+    m_youtubePlaybackFormats.insert(Videos::LQ);
 
-void Settings::setYouTubePlaybackQualitySet(const QVariantList &qualityList) {
-    for (int i = 0; i < qualityList.size(); i++) {
-        m_youtubePlaybackSet.insert(qualityList.at(i).toInt());
-    }
-
-    m_youtubePlaybackSet.insert(18);
-    emit youtubePlaybackQualityChanged(m_youtubePlaybackSet);
+    emit youtubePlaybackFormatsChanged(m_youtubePlaybackFormats);
     emit enableYouTube1080PlaybackChanged();
     emit enableYouTube720PlaybackChanged();
     emit enableYouTube480PlaybackChanged();
     emit enableYouTube360PlaybackChanged();
 }
 
-void Settings::setYouTubeDownloadQualitySet(const QVariantList &qualityList) {
-    for (int i = 0; i < qualityList.size(); i++) {
-        m_youtubeDownloadSet.insert(qualityList.at(i).toInt());
+void Settings::setYouTubeDownloadFormats(QVariantList formats) {
+    while (!formats.isEmpty()) {
+        m_youtubeDownloadFormats.insert(formats.takeFirst().toInt());
     }
 
-    m_youtubeDownloadSet.insert(18);
-    emit youtubeDownloadQualityChanged(m_youtubeDownloadSet);
+    m_youtubeDownloadFormats.insert(Videos::LQ);
+
+    emit youtubeDownloadFormatsChanged(m_youtubeDownloadFormats);
     emit enableYouTube1080DownloadChanged();
     emit enableYouTube720DownloadChanged();
     emit enableYouTube480DownloadChanged();
     emit enableYouTube360DownloadChanged();
 }
 
-void Settings::setDailymotionPlaybackQualitySet(const QVariantList &qualityList) {
-    for (int i = 0; i < qualityList.size(); i++) {
-        m_dailymotionPlaybackSet.insert(qualityList.at(i).toByteArray());
+void Settings::setDailymotionPlaybackFormats(QVariantList formats) {
+    while (!formats.isEmpty()) {
+        m_dailymotionPlaybackFormats.insert(formats.takeFirst().toInt());
     }
 
-    m_dailymotionPlaybackSet.insert("380");
-    emit dailymotionPlaybackQualityChanged(m_dailymotionPlaybackSet);
+    m_dailymotionPlaybackFormats.insert(Videos::Normal);
+
+    emit dailymotionPlaybackFormatsChanged(m_dailymotionPlaybackFormats);
+    emit enableDailymotion1080PlaybackChanged();
     emit enableDailymotion720PlaybackChanged();
     emit enableDailymotion480PlaybackChanged();
 }
 
-void Settings::setDailymotionDownloadQualitySet(const QVariantList &qualityList) {
-    for (int i = 0; i < qualityList.size(); i++) {
-        m_dailymotionDownloadSet.insert(qualityList.at(i).toByteArray());
+void Settings::setDailymotionDownloadFormats(QVariantList formats) {
+    while (!formats.isEmpty()) {
+        m_dailymotionDownloadFormats.insert(formats.takeFirst().toInt());
     }
 
-    m_dailymotionDownloadSet.insert("380");
-    emit dailymotionDownloadQualityChanged(m_dailymotionDownloadSet);
+    m_dailymotionDownloadFormats.insert(Videos::Normal);
+
+    emit dailymotionDownloadFormatsChanged(m_dailymotionDownloadFormats);
+    emit enableDailymotion1080DownloadChanged();
     emit enableDailymotion720DownloadChanged();
     emit enableDailymotion480DownloadChanged();
 }
 
-void Settings::setVimeoPlaybackQualitySet(const QVariantList &qualityList) {
-    for (int i = 0; i < qualityList.size(); i++) {
-        m_vimeoPlaybackSet.insert(qualityList.at(i).toByteArray());
+void Settings::setVimeoPlaybackFormats(QVariantList formats) {
+    while (!formats.isEmpty()) {
+        m_vimeoPlaybackFormats.insert(formats.takeFirst().toInt());
     }
 
-    m_vimeoPlaybackSet.insert("mobile");
-    emit vimeoPlaybackQualityChanged(m_vimeoPlaybackSet);
+    m_vimeoPlaybackFormats.insert(Videos::LQ);
+
+    emit vimeoPlaybackFormatsChanged(m_vimeoPlaybackFormats);
     emit enableVimeo720PlaybackChanged();
     emit enableVimeo360PlaybackChanged();
 }
 
-void Settings::setVimeoDownloadQualitySet(const QVariantList &qualityList) {
-    for (int i = 0; i < qualityList.size(); i++) {
-        m_vimeoDownloadSet.insert(qualityList.at(i).toByteArray());
+void Settings::setVimeoDownloadFormats(QVariantList formats) {
+    while (!formats.isEmpty()) {
+        m_vimeoDownloadFormats.insert(formats.takeFirst().toInt());
     }
 
-    m_vimeoDownloadSet.insert("mobile");
-    emit vimeoDownloadQualityChanged(m_vimeoDownloadSet);
+    m_vimeoDownloadFormats.insert(Videos::LQ);
+
+    emit vimeoDownloadFormatsChanged(m_vimeoDownloadFormats);
     emit enableVimeo720DownloadChanged();
     emit enableVimeo360DownloadChanged();
 }
 
 void Settings::setEnableYouTube1080Playback(bool enable) {
     if (enable) {
-        m_youtubePlaybackSet.insert(37);
+        m_youtubePlaybackFormats.insert(Videos::SuperHD);
     }
     else {
-        m_youtubePlaybackSet.remove(37);
+        m_youtubePlaybackFormats.remove(Videos::SuperHD);
     }
 
-    emit youtubePlaybackQualityChanged(m_youtubePlaybackSet);
+    emit youtubePlaybackFormatsChanged(m_youtubePlaybackFormats);
     emit enableYouTube1080PlaybackChanged();
 }
 
 void Settings::setEnableYouTube720Playback(bool enable) {
     if (enable) {
-        m_youtubePlaybackSet.insert(22);
+        m_youtubePlaybackFormats.insert(Videos::HD);
     }
     else {
-        m_youtubePlaybackSet.remove(22);
+        m_youtubePlaybackFormats.remove(Videos::HD);
     }
 
-    emit youtubePlaybackQualityChanged(m_youtubePlaybackSet);
+    emit youtubePlaybackFormatsChanged(m_youtubePlaybackFormats);
     emit enableYouTube720PlaybackChanged();
 }
 
 void Settings::setEnableYouTube480Playback(bool enable) {
     if (enable) {
-        m_youtubePlaybackSet.insert(35);
+        m_youtubePlaybackFormats.insert(Videos::HQ);
     }
     else {
-        m_youtubePlaybackSet.remove(35);
+        m_youtubePlaybackFormats.remove(Videos::HQ);
     }
 
-    emit youtubePlaybackQualityChanged(m_youtubePlaybackSet);
+    emit youtubePlaybackFormatsChanged(m_youtubePlaybackFormats);
     emit enableYouTube480PlaybackChanged();
 }
 
 void Settings::setEnableYouTube360Playback(bool enable) {
     if (enable) {
-        m_youtubePlaybackSet.insert(34);
+        m_youtubePlaybackFormats.insert(Videos::Normal);
     }
     else {
-        m_youtubePlaybackSet.remove(34);
+        m_youtubePlaybackFormats.remove(Videos::Normal);
     }
 
-    emit youtubePlaybackQualityChanged(m_youtubePlaybackSet);
+    emit youtubePlaybackFormatsChanged(m_youtubePlaybackFormats);
     emit enableYouTube360PlaybackChanged();
 }
 
 void Settings::setEnableYouTube1080Download(bool enable) {
     if (enable) {
-        m_youtubeDownloadSet.insert(37);
+        m_youtubeDownloadFormats.insert(Videos::SuperHD);
     }
     else {
-        m_youtubeDownloadSet.remove(37);
+        m_youtubeDownloadFormats.remove(Videos::SuperHD);
     }
 
-    emit youtubeDownloadQualityChanged(m_youtubeDownloadSet);
+    emit youtubeDownloadFormatsChanged(m_youtubeDownloadFormats);
     emit enableYouTube1080DownloadChanged();
 }
 
 void Settings::setEnableYouTube720Download(bool enable) {
     if (enable) {
-        m_youtubeDownloadSet.insert(22);
+        m_youtubeDownloadFormats.insert(Videos::HD);
     }
     else {
-        m_youtubeDownloadSet.remove(22);
+        m_youtubeDownloadFormats.remove(Videos::HD);
     }
 
-    emit youtubeDownloadQualityChanged(m_youtubeDownloadSet);
+    emit youtubeDownloadFormatsChanged(m_youtubeDownloadFormats);
     emit enableYouTube720DownloadChanged();
 }
 
 void Settings::setEnableYouTube480Download(bool enable) {
     if (enable) {
-        m_youtubeDownloadSet.insert(35);
+        m_youtubeDownloadFormats.insert(Videos::HQ);
     }
     else {
-        m_youtubeDownloadSet.remove(35);
+        m_youtubeDownloadFormats.remove(Videos::HQ);
     }
 
-    emit youtubeDownloadQualityChanged(m_youtubeDownloadSet);
+    emit youtubeDownloadFormatsChanged(m_youtubeDownloadFormats);
     emit enableYouTube480DownloadChanged();
 }
 
 void Settings::setEnableYouTube360Download(bool enable) {
     if (enable) {
-        m_youtubeDownloadSet.insert(34);
+        m_youtubeDownloadFormats.insert(Videos::Normal);
     }
     else {
-        m_youtubeDownloadSet.remove(34);
+        m_youtubeDownloadFormats.remove(Videos::Normal);
     }
 
-    emit youtubeDownloadQualityChanged(m_youtubeDownloadSet);
+    emit youtubeDownloadFormatsChanged(m_youtubeDownloadFormats);
     emit enableYouTube360DownloadChanged();
 }
 
+void Settings::setEnableDailymotion1080Playback(bool enable) {
+    if (enable) {
+        m_dailymotionPlaybackFormats.insert(Videos::SuperHD);
+    }
+    else {
+        m_dailymotionPlaybackFormats.remove(Videos::SuperHD);
+    }
+
+    emit dailymotionPlaybackFormatsChanged(m_dailymotionPlaybackFormats);
+    emit enableDailymotion1080PlaybackChanged();
+}
+
 void Settings::setEnableDailymotion720Playback(bool enable) {
     if (enable) {
-        m_dailymotionPlaybackSet.insert("720");
+        m_dailymotionPlaybackFormats.insert(Videos::HD);
     }
     else {
-        m_dailymotionPlaybackSet.remove("720");
+        m_dailymotionPlaybackFormats.remove(Videos::HD);
     }
 
-    emit dailymotionPlaybackQualityChanged(m_dailymotionPlaybackSet);
+    emit dailymotionPlaybackFormatsChanged(m_dailymotionPlaybackFormats);
     emit enableDailymotion720PlaybackChanged();
 }
 
 void Settings::setEnableDailymotion480Playback(bool enable) {
     if (enable) {
-        m_dailymotionPlaybackSet.insert("480");
+        m_dailymotionPlaybackFormats.insert(Videos::HQ);
     }
     else {
-        m_dailymotionPlaybackSet.remove("480");
+        m_dailymotionPlaybackFormats.remove(Videos::HQ);
     }
 
-    emit dailymotionPlaybackQualityChanged(m_dailymotionPlaybackSet);
+    emit dailymotionPlaybackFormatsChanged(m_dailymotionPlaybackFormats);
     emit enableDailymotion480PlaybackChanged();
 }
 
+void Settings::setEnableDailymotion1080Download(bool enable) {
+    if (enable) {
+        m_dailymotionDownloadFormats.insert(Videos::SuperHD);
+    }
+    else {
+        m_dailymotionDownloadFormats.remove(Videos::SuperHD);
+    }
+
+    emit dailymotionDownloadFormatsChanged(m_dailymotionDownloadFormats);
+    emit enableDailymotion1080DownloadChanged();
+}
+
 void Settings::setEnableDailymotion720Download(bool enable) {
     if (enable) {
-        m_dailymotionDownloadSet.insert("720");
+        m_dailymotionDownloadFormats.insert(Videos::HD);
     }
     else {
-        m_dailymotionDownloadSet.remove("720");
+        m_dailymotionDownloadFormats.remove(Videos::HD);
     }
 
-    emit dailymotionDownloadQualityChanged(m_dailymotionDownloadSet);
+    emit dailymotionDownloadFormatsChanged(m_dailymotionDownloadFormats);
     emit enableDailymotion720DownloadChanged();
 }
 
 void Settings::setEnableDailymotion480Download(bool enable) {
     if (enable) {
-        m_dailymotionDownloadSet.insert("480");
+        m_dailymotionDownloadFormats.insert(Videos::HQ);
     }
     else {
-        m_dailymotionDownloadSet.remove("480");
+        m_dailymotionDownloadFormats.remove(Videos::HQ);
     }
 
-    emit dailymotionDownloadQualityChanged(m_dailymotionDownloadSet);
+    emit dailymotionDownloadFormatsChanged(m_dailymotionDownloadFormats);
     emit enableDailymotion480DownloadChanged();
 }
 
 void Settings::setEnableVimeo720Playback(bool enable) {
     if (enable) {
-        m_vimeoPlaybackSet.insert("hd");
+        m_vimeoPlaybackFormats.insert(Videos::HQ);
     }
     else {
-        m_vimeoPlaybackSet.remove("hd");
+        m_vimeoPlaybackFormats.remove(Videos::HQ);
     }
 
-    emit vimeoPlaybackQualityChanged(m_vimeoPlaybackSet);
+    emit vimeoPlaybackFormatsChanged(m_vimeoPlaybackFormats);
     emit enableVimeo720PlaybackChanged();
 }
 
 void Settings::setEnableVimeo360Playback(bool enable) {
     if (enable) {
-        m_vimeoPlaybackSet.insert("sd");
+        m_vimeoPlaybackFormats.insert(Videos::Normal);
     }
     else {
-        m_vimeoPlaybackSet.remove("sd");
+        m_vimeoPlaybackFormats.remove(Videos::Normal);
     }
 
-    emit vimeoPlaybackQualityChanged(m_vimeoPlaybackSet);
+    emit vimeoPlaybackFormatsChanged(m_vimeoPlaybackFormats);
     emit enableVimeo360PlaybackChanged();
 }
 
 void Settings::setEnableVimeo720Download(bool enable) {
     if (enable) {
-        m_vimeoDownloadSet.insert("hd");
+        m_vimeoDownloadFormats.insert(Videos::HD);
     }
     else {
-        m_vimeoDownloadSet.remove("hd");
+        m_vimeoDownloadFormats.remove(Videos::HD);
     }
 
-    emit vimeoDownloadQualityChanged(m_vimeoDownloadSet);
+    emit vimeoDownloadFormatsChanged(m_vimeoDownloadFormats);
     emit enableVimeo720DownloadChanged();
 }
 
 void Settings::setEnableVimeo360Download(bool enable) {
     if (enable) {
-        m_vimeoDownloadSet.insert("sd");
+        m_vimeoDownloadFormats.insert(Videos::Normal);
     }
     else {
-        m_vimeoDownloadSet.remove("sd");
+        m_vimeoDownloadFormats.remove(Videos::Normal);
     }
 
-    emit vimeoDownloadQualityChanged(m_vimeoDownloadSet);
+    emit vimeoDownloadFormatsChanged(m_vimeoDownloadFormats);
     emit enableVimeo360DownloadChanged();
 
 }
@@ -598,6 +661,7 @@ void Settings::setShowSearchLanguage(bool show) {
     }
 }
 
+#if (defined (SYMBIAN_OS)) || (defined (MEEGO_EDITION_HARMATTAN))
 void Settings::setTheme(const QString &theme) {
     if (theme != this->theme()) {
         m_theme = theme;
@@ -605,6 +669,7 @@ void Settings::setTheme(const QString &theme) {
     }
 }
 
+#ifdef MEEGO_EDITION_HARMATTAN
 void Settings::setActiveColor(const QString &color) {
     if (color != this->activeColor()) {
         m_activeColor = color;
@@ -618,6 +683,8 @@ void Settings::setActiveColorString(const QString &colorString) {
         emit activeColorStringChanged(colorString);
     }
 }
+#endif
+#endif
 
 void Settings::setLanguage(const QString &lang) {
     if (lang != this->language()) {
@@ -640,6 +707,7 @@ void Settings::setMediaPlayer(const QString &player) {
     }
 }
 
+#ifndef SYMBIAN_OS
 void Settings::setMediaPlayerCommand(const QString &command) {
     if (command != this->mediaPlayerCommand()) {
         m_command = command;
@@ -653,6 +721,7 @@ void Settings::setBackgroundPlaybackEnabled(bool enabled) {
         emit backgroundPlaybackEnabledChanged(enabled);
     }
 }
+#endif
 
 void Settings::setScreenOrientation(ScreenOrientation::Orientation orientation) {
     if (orientation != this->screenOrientation()) {
@@ -747,6 +816,7 @@ void Settings::onNetworkProxyAuthenticationRequested(const QNetworkProxy &proxy,
     authenticator->setPassword(this->networkProxyPassword());
 }
 
+#ifdef Q_WS_MAEMO_5
 void Settings::setEventFeedEnabled(bool enabled) {
     if (enabled != this->eventFeedEnabled()) {
         m_eventFeedEnabled = enabled;
@@ -755,21 +825,11 @@ void Settings::setEventFeedEnabled(bool enabled) {
 }
 
 bool Settings::eventFeedInstalled() const {
-#ifdef Q_WS_MAEMO_5
-    QDir dir;
+    return QDir().exists("/opt/hildonevents/bin/hildonevents");
 
-    return dir.exists("/opt/hildonevents/bin/hildonevents");
-#elif defined (MEEGO_EDITION_HARMATTAN)
-    return true;
-#else
-    return false;
-#endif
 }
+#endif
 
-void Settings::setCuteTubePlayerEnabled() {
-#ifdef Q_OS_SYMBIAN
-    using namespace QtMobility;
-    QSystemDeviceInfo info;
-    m_cuteTubePlayerEnabled = (info.model() == "700") || (info.model() == "701") || (info.model() == "808");
-#endif
+void Settings::setCuteTubePlayerEnabled(bool enabled) {
+    m_cuteTubePlayerEnabled = enabled;
 }
