@@ -232,15 +232,16 @@ QString UrlGrabber::decryptYouTubeSignature(const QString &s) {
     }
         break;
     case 83: {
-        signature = s.at(52)
-                + Utils::reverseString(s.mid(56, 26))
-                + s.at(2)
-                + Utils::reverseString(s.mid(53, 2))
-                + s.at(82)
-                + Utils::reverseString(s.mid(37, 15))
-                + s.at(55)
-                + Utils::reverseString(s.mid(3, 33))
-                + s.at(36);
+        signature = s.at(6)
+                + s.mid(3, 3)
+                + s.at(33)
+                + s.mid(7, 17)
+                + s.at(0)
+                + s.mid(25, 8)
+                + s.at(53)
+                + s.mid(34, 19)
+                + s.at(24)
+                + s.mid(54);
     }
         break;
     case 82: {
@@ -258,6 +259,19 @@ QString UrlGrabber::decryptYouTubeSignature(const QString &s) {
                 + s.at(34);
     }
         break;
+    case 81: {
+        signature = s.at(6)
+                + s.mid(3, 3)
+                + s.at(33)
+                + s.mid(7, 17)
+                + s.at(0)
+                + s.mid(25, 8)
+                + s.at(2)
+                + s.mid(34, 19)
+                + s.at(24)
+                + s.mid(54, 27);
+    }
+        break;
     default:
         break;
     }
