@@ -11,6 +11,7 @@
 #include <QAction>
 #include <QLabel>
 #include <QGridLayout>
+#include <QMaemo5Style>
 
 DailymotionSubscriptionsTab::DailymotionSubscriptionsTab(QWidget *parent) :
     AbstractTab(parent),
@@ -19,7 +20,7 @@ DailymotionSubscriptionsTab::DailymotionSubscriptionsTab(QWidget *parent) :
     m_contextMenu(new QMenu(this)),
     m_unsubscribeAction(m_contextMenu->addAction(tr("Unsubscribe"), this, SLOT(unsubscribe()))),
     m_videosAction(new QAction(tr("Latest videos"), this)),
-    m_noResultsLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No subscriptions found")), this)),
+    m_noResultsLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No subscriptions found")), this)),
     m_grid(new QGridLayout(this))
 {
     this->addAction(m_videosAction);
