@@ -8,6 +8,7 @@
 #include <QDialogButtonBox>
 #include <QGridLayout>
 #include <QScrollArea>
+#include <QMaemo5Style>
 
 VimeoCommentDialog::VimeoCommentDialog(QSharedPointer<VideoItem> video, QSharedPointer<CommentItem> initialComment, QWidget *parent) :
     AbstractDialog(parent),
@@ -15,7 +16,7 @@ VimeoCommentDialog::VimeoCommentDialog(QSharedPointer<VideoItem> video, QSharedP
     m_initialComment(initialComment),
     m_commentEdit(new QTextEdit(this)),
     m_avatar(!m_initialComment ? 0 : new ThumbnailLabel(this)),
-    m_initialCommentLabel(m_initialComment.isNull() ? 0 : new QLabel(QString("<p style='font-size:20px;color:#4d4d4d;'>%1</p>").arg(m_initialComment.data()->body()), this)),
+    m_initialCommentLabel(m_initialComment.isNull() ? 0 : new QLabel(QString("<p style='font-size:20px;color:%1;'>%2</p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(m_initialComment.data()->body()), this)),
     m_buttonBox(new QDialogButtonBox(Qt::Vertical, this)),
     m_doneButton(m_buttonBox->addButton(tr("Done"), QDialogButtonBox::AcceptRole)),
     m_scrollArea(new QScrollArea(this)),
