@@ -9,6 +9,7 @@
 #include <QLabel>
 #include <QGridLayout>
 #include <QAction>
+#include <QMaemo5Style>
 
 YouTubeUserListTab::YouTubeUserListTab(const QString &userId, QWidget *parent) :
     AbstractTab(parent),
@@ -16,7 +17,7 @@ YouTubeUserListTab::YouTubeUserListTab(const QString &userId, QWidget *parent) :
     m_model(new YouTubeUserListModel(this)),
     m_listView(new ListView(this)),
     m_videosAction(new QAction(tr("Latest videos"), this)),
-    m_noResultsLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No subscriptions found")), this)),
+    m_noResultsLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No subscriptions found")), this)),
     m_grid(new QGridLayout(this))
 {
     this->addAction(m_videosAction);
